@@ -2,10 +2,11 @@ package Test::Mojo::Trim;
 
 use strict;
 
+use Mojo::DOM;
 use Mojo::Base 'Test::Mojo';
 use Mojo::Util 'squish';
 
-our $VERSION = '0.0902'; # VERSION
+our $VERSION = '0.0903'; # VERSION
 # ABSTRACT: Trim strings for Test::Mojo
 
 sub trimmed_content_is {
@@ -24,13 +25,10 @@ sub trimmed_content_is {
 
     if(defined $error && length $error) {
         $desc .= (defined $error && length $error ? " (Error: $error)" : '');
-        my $table = $dom->find('#context table');
-        if($table) {
-            $table->find('tr')->each(sub {
-                $desc .= $_->all_text . "\n";
-            });
-            $got = '<see error>';
-        }
+        my $table = $dom->find('#context table')->each(sub {
+            $desc .= $_->find('td')->map(sub { $_->text })->join(' ');
+        });
+        $got = '<see error>';
     }
 
     return $self->_test('is', $got, $value, $desc);
@@ -50,14 +48,10 @@ Test::Mojo::Trim - Trim strings for Test::Mojo
 
 =head1 VERSION
 
-Version 0.0902, released 2015-02-06.
+Version 0.0903, released 2015-02-12.
 
 =head1 SYNOPSIS
 
-=head1 DESCRIPTION
-
-Test::Mojo::Trim is an extension to Test::Mojo, that adds an additional string comparison function.
-
 =for html <p><a style="float: left;" href="https://travis-ci.org/Csson/p5-test-mojo-trim"><img src="https://travis-ci.org/Csson/p5-test-mojo-trim.svg?branch=master">&nbsp;</a>
 
     use Mojo::Base -strict;
@@ -82,6 +76,10 @@ Test::Mojo::Trim is an extension to Test::Mojo, that adds an additional string c
         <p>A paragraph.</p>
     </div>
 
+=head1 DESCRIPTION
+
+Test::Mojo::Trim is an extension to Test::Mojo, that adds an additional string comparison function.
+
 =head1 METHODS
 
 L<Test::Mojo::Trim> inherits all methods from L<Test::Mojo> and implements the following new one.
@@ -92,6 +90,7 @@ L<Test::Mojo::Trim> inherits all methods from L<Test::Mojo> and implements the f
 
 Removes all whitespace between tags from the two strings that are compared.
 That is, if a E<gt> and E<lt> is separated only by whitespace, that whitespace is removed.
+Any leading or trailing whitespace is also removed.
 
 =head1 SEE ALSO
 
@@ -121,7 +120,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
